@@ -566,7 +566,7 @@ void QWebSocketPrivate::open(const QNetworkRequest &request,
 void QWebSocketPrivate::ping(const QByteArray &payload)
 {
     QByteArray payloadTruncated = payload.left(125);
-    m_pingTimer.restart();
+    m_pingTimer.start();
     quint32 maskingKey = 0;
     if (m_mustMask)
         maskingKey = generateMaskingKey();
@@ -735,8 +735,12 @@ void QWebSocketPrivate::makeConnections(QTcpSocket *pTcpSocket)
  */
 void QWebSocketPrivate::releaseConnections(const QTcpSocket *pTcpSocket)
 {
-    if (Q_LIKELY(pTcpSocket))
+    if (Q_LIKELY(pTcpSocket)) {
+        // Explicitly disconnect this signal to avoid warning being printed about a destroyed-signal
+        // being disconnected with the wildcard disconnect below
+        disconnect(pTcpSocket, &QObject::destroyed, this, &QWebSocketPrivate::socketDestroyed);
         pTcpSocket->disconnect();
+    }
     m_dataProcessor->disconnect();
 }
 
@@ -1195,6 +1199,24 @@ void QWebSocketPrivate::processHandshake(QTcpSocket *pSocket)
     }
 }
 
+/*!
+    \internal
+*/
+static QString removeZoneId(const QString& hostPort)
+{
+    const auto closeBracketIndex = hostPort.indexOf(u']');
+    const auto percentIndex = hostPort.indexOf(u'%');
+    // Only perform a minimal sanity check, as at this point the
+    // URI parts host and port were already used successfully to
+    // connect to the host.
+    if (!hostPort.startsWith(u'[') || closeBracketIndex == -1
+        || percentIndex == -1 || percentIndex > closeBracketIndex) {
+        return hostPort;
+    }
+
+    return hostPort.left(percentIndex) + hostPort.mid(closeBracketIndex);
+}
+
 /*!
     \internal
  */
@@ -1251,7 +1273,8 @@ void QWebSocketPrivate::processStateChanged(QAbstractSocket::SocketState socketS
             const auto format = QUrl::RemoveScheme | QUrl::RemoveUserInfo
                                 | QUrl::RemovePath | QUrl::RemoveQuery
                                 | QUrl::RemoveFragment;
-            const QString host = m_request.url().toString(format).mid(2);
+            // mid(2) removes the prefix "//" from the remaining url
+            const QString host = removeZoneId(m_request.url().toString(format).mid(2));
             const QString handshake = createHandShakeRequest(m_resourceName,
                                                              host,
                                                              origin(),
