@@ -1,30 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 Kurt Pattyn <pattyn.kurt@gmail.com>.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the test suite of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:GPL-EXCEPT$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 Kurt Pattyn <pattyn.kurt@gmail.com>.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 #include <QtTest/QtTest>
 #include <QtTest/qtestcase.h>
 #include <QtTest/QSignalSpy>
@@ -43,6 +18,9 @@ const quint8 RSV3 = 0x10;
 
 QT_USE_NAMESPACE
 
+using namespace std::chrono_literals;
+constexpr std::chrono::milliseconds DefaultIdleTimeout = 500ms;
+
 Q_DECLARE_METATYPE(QWebSocketProtocol::CloseCode)
 Q_DECLARE_METATYPE(QWebSocketProtocol::OpCode)
 
@@ -247,20 +225,20 @@ void tst_DataProcessor::goodBinaryFrame()
 
     data.append(char(FIN | QWebSocketProtocol::OpCodeBinary));
 
-    if (payload.length() < 126)
+    if (payload.size() < 126)
     {
-        data.append(char(payload.length()));
+        data.append(char(payload.size()));
     }
-    else if (payload.length() < 65536)
+    else if (payload.size() < 65536)
     {
-        quint16 swapped = qToBigEndian<quint16>(payload.length());
+        quint16 swapped = qToBigEndian<quint16>(payload.size());
         const char *wireRepresentation
                 = static_cast<const char *>(static_cast<const void *>(&swapped));
         data.append(char(126)).append(wireRepresentation, 2);
     }
     else
     {
-        quint64 swapped = qToBigEndian<quint64>(payload.length());
+        quint64 swapped = qToBigEndian<quint64>(payload.size());
         const char *wireRepresentation
                 = static_cast<const char *>(static_cast<const void *>(&swapped));
         data.append(char(127)).append(wireRepresentation, 8);
@@ -281,18 +259,18 @@ void tst_DataProcessor::goodBinaryFrame()
     QSignalSpy textFrameReceivedSpy(&dataProcessor, SIGNAL(textFrameReceived(QString,bool)));
     QSignalSpy textMessageReceivedSpy(&dataProcessor, SIGNAL(textMessageReceived(QString)));
     dataProcessor.process(&buffer);
-    QCOMPARE(errorReceivedSpy.count(), 0);
-    QCOMPARE(pingReceivedSpy.count(), 0);
-    QCOMPARE(pongReceivedSpy.count(), 0);
-    QCOMPARE(closeReceivedSpy.count(), 0);
-    QCOMPARE(binaryFrameReceivedSpy.count(), 1);
-    QCOMPARE(binaryMessageReceivedSpy.count(), 1);
-    QCOMPARE(textFrameReceivedSpy.count(), 0);
-    QCOMPARE(textMessageReceivedSpy.count(), 0);
+    QCOMPARE(errorReceivedSpy.size(), 0);
+    QCOMPARE(pingReceivedSpy.size(), 0);
+    QCOMPARE(pongReceivedSpy.size(), 0);
+    QCOMPARE(closeReceivedSpy.size(), 0);
+    QCOMPARE(binaryFrameReceivedSpy.size(), 1);
+    QCOMPARE(binaryMessageReceivedSpy.size(), 1);
+    QCOMPARE(textFrameReceivedSpy.size(), 0);
+    QCOMPARE(textMessageReceivedSpy.size(), 0);
     QList<QVariant> arguments = binaryFrameReceivedSpy.takeFirst();
-    QCOMPARE(arguments.at(0).toByteArray().length(), payload.length());
+    QCOMPARE(arguments.at(0).toByteArray().size(), payload.size());
     arguments = binaryMessageReceivedSpy.takeFirst();
-    QCOMPARE(arguments.at(0).toByteArray().length(), payload.length());
+    QCOMPARE(arguments.at(0).toByteArray().size(), payload.size());
     buffer.close();
 }
 
@@ -341,20 +319,20 @@ void tst_DataProcessor::goodTextFrame()
 
     data.append(char(FIN | QWebSocketProtocol::OpCodeText));
 
-    if (payload.length() < 126)
+    if (payload.size() < 126)
     {
-        data.append(char(payload.length()));
+        data.append(char(payload.size()));
     }
-    else if (payload.length() < 65536)
+    else if (payload.size() < 65536)
     {
-        quint16 swapped = qToBigEndian<quint16>(payload.length());
+        quint16 swapped = qToBigEndian<quint16>(payload.size());
         const char *wireRepresentation
                 = static_cast<const char *>(static_cast<const void *>(&swapped));
         data.append(char(126)).append(wireRepresentation, 2);
     }
     else
     {
-        quint64 swapped = qToBigEndian<quint64>(payload.length());
+        quint64 swapped = qToBigEndian<quint64>(payload.size());
         const char *wireRepresentation
                 = static_cast<const char *>(static_cast<const void *>(&swapped));
         data.append(char(127)).append(wireRepresentation, 8);
@@ -377,18 +355,18 @@ void tst_DataProcessor::goodTextFrame()
 
     dataProcessor.process(&buffer);
 
-    QCOMPARE(errorReceivedSpy.count(), 0);
-    QCOMPARE(pingReceivedSpy.count(), 0);
-    QCOMPARE(pongReceivedSpy.count(), 0);
-    QCOMPARE(closeReceivedSpy.count(), 0);
-    QCOMPARE(textFrameReceivedSpy.count(), 1);
-    QCOMPARE(textMessageReceivedSpy.count(), 1);
-    QCOMPARE(binaryFrameReceivedSpy.count(), 0);
-    QCOMPARE(binaryMessageReceivedSpy.count(), 0);
+    QCOMPARE(errorReceivedSpy.size(), 0);
+    QCOMPARE(pingReceivedSpy.size(), 0);
+    QCOMPARE(pongReceivedSpy.size(), 0);
+    QCOMPARE(closeReceivedSpy.size(), 0);
+    QCOMPARE(textFrameReceivedSpy.size(), 1);
+    QCOMPARE(textMessageReceivedSpy.size(), 1);
+    QCOMPARE(binaryFrameReceivedSpy.size(), 0);
+    QCOMPARE(binaryMessageReceivedSpy.size(), 0);
     QList<QVariant> arguments = textFrameReceivedSpy.takeFirst();
-    QCOMPARE(arguments.at(0).toString().length(), size);
+    QCOMPARE(arguments.at(0).toString().size(), size);
     arguments = textMessageReceivedSpy.takeFirst();
-    QCOMPARE(arguments.at(0).toString().length(), size);
+    QCOMPARE(arguments.at(0).toString().size(), size);
     buffer.close();
 }
 
@@ -414,14 +392,14 @@ void tst_DataProcessor::goodControlFrame()
     buffer.setData(data);
     buffer.open(QIODevice::ReadOnly);
     dataProcessor.process(&buffer);
-    QCOMPARE(errorReceivedSpy.count(), 0);
-    QCOMPARE(textFrameReceivedSpy.count(), 0);
-    QCOMPARE(textMessageReceivedSpy.count(), 0);
-    QCOMPARE(binaryFrameReceivedSpy.count(), 0);
-    QCOMPARE(binaryMessageReceivedSpy.count(), 0);
-    QCOMPARE(closeFrameReceivedSpy.count(), 0);
-    QCOMPARE(pongReceivedSpy.count(), 0);
-    QCOMPARE(pingReceivedSpy.count(), 1);
+    QCOMPARE(errorReceivedSpy.size(), 0);
+    QCOMPARE(textFrameReceivedSpy.size(), 0);
+    QCOMPARE(textMessageReceivedSpy.size(), 0);
+    QCOMPARE(binaryFrameReceivedSpy.size(), 0);
+    QCOMPARE(binaryMessageReceivedSpy.size(), 0);
+    QCOMPARE(closeFrameReceivedSpy.size(), 0);
+    QCOMPARE(pongReceivedSpy.size(), 0);
+    QCOMPARE(pingReceivedSpy.size(), 1);
     buffer.close();
 
     data.clear();
@@ -432,14 +410,14 @@ void tst_DataProcessor::goodControlFrame()
     buffer.setData(data);
     buffer.open(QIODevice::ReadOnly);
     dataProcessor.process(&buffer);
-    QCOMPARE(errorReceivedSpy.count(), 0);
-    QCOMPARE(textFrameReceivedSpy.count(), 0);
-    QCOMPARE(textMessageReceivedSpy.count(), 0);
-    QCOMPARE(binaryFrameReceivedSpy.count(), 0);
-    QCOMPARE(binaryMessageReceivedSpy.count(), 0);
-    QCOMPARE(closeFrameReceivedSpy.count(), 0);
-    QCOMPARE(pingReceivedSpy.count(), 0);
-    QCOMPARE(pongReceivedSpy.count(), 1);
+    QCOMPARE(errorReceivedSpy.size(), 0);
+    QCOMPARE(textFrameReceivedSpy.size(), 0);
+    QCOMPARE(textMessageReceivedSpy.size(), 0);
+    QCOMPARE(binaryFrameReceivedSpy.size(), 0);
+    QCOMPARE(binaryMessageReceivedSpy.size(), 0);
+    QCOMPARE(closeFrameReceivedSpy.size(), 0);
+    QCOMPARE(pingReceivedSpy.size(), 0);
+    QCOMPARE(pongReceivedSpy.size(), 1);
     buffer.close();
 }
 
@@ -564,14 +542,14 @@ void tst_DataProcessor::goodOpcodes()
 
     dataProcessor.process(&buffer);
 
-    QCOMPARE(errorReceivedSpy.count(), 0);
-    QCOMPARE(pingReceivedSpy.count(), opCode == QWebSocketProtocol::OpCodePing ? 1 : 0);
-    QCOMPARE(pongReceivedSpy.count(), opCode == QWebSocketProtocol::OpCodePong ? 1 : 0);
-    QCOMPARE(closeReceivedSpy.count(), opCode == QWebSocketProtocol::OpCodeClose ? 1 : 0);
-    QCOMPARE(textFrameReceivedSpy.count(), opCode == QWebSocketProtocol::OpCodeText ? 1 : 0);
-    QCOMPARE(textMessageReceivedSpy.count(), opCode == QWebSocketProtocol::OpCodeText ? 1 : 0);
-    QCOMPARE(binaryFrameReceivedSpy.count(), opCode == QWebSocketProtocol::OpCodeBinary ? 1 : 0);
-    QCOMPARE(binaryMessageReceivedSpy.count(), opCode == QWebSocketProtocol::OpCodeBinary ? 1 : 0);
+    QCOMPARE(errorReceivedSpy.size(), 0);
+    QCOMPARE(pingReceivedSpy.size(), opCode == QWebSocketProtocol::OpCodePing ? 1 : 0);
+    QCOMPARE(pongReceivedSpy.size(), opCode == QWebSocketProtocol::OpCodePong ? 1 : 0);
+    QCOMPARE(closeReceivedSpy.size(), opCode == QWebSocketProtocol::OpCodeClose ? 1 : 0);
+    QCOMPARE(textFrameReceivedSpy.size(), opCode == QWebSocketProtocol::OpCodeText ? 1 : 0);
+    QCOMPARE(textMessageReceivedSpy.size(), opCode == QWebSocketProtocol::OpCodeText ? 1 : 0);
+    QCOMPARE(binaryFrameReceivedSpy.size(), opCode == QWebSocketProtocol::OpCodeBinary ? 1 : 0);
+    QCOMPARE(binaryMessageReceivedSpy.size(), opCode == QWebSocketProtocol::OpCodeBinary ? 1 : 0);
 
     buffer.close();
 }
@@ -589,7 +567,7 @@ void tst_DataProcessor::goodCloseFrame()
     data.append(char(FIN | QWebSocketProtocol::OpCodeClose));
     if (swapped != 0)
     {
-        data.append(char(payload.length() + 2)).append(wireRepresentation, 2).append(payload.toUtf8());
+        data.append(char(payload.size() + 2)).append(wireRepresentation, 2).append(payload.toUtf8());
     }
     else
     {
@@ -613,17 +591,17 @@ void tst_DataProcessor::goodCloseFrame()
 
     dataProcessor.process(&buffer);
 
-    QCOMPARE(errorReceivedSpy.count(), 0);
-    QCOMPARE(pingReceivedSpy.count(), 0);
-    QCOMPARE(pongReceivedSpy.count(), 0);
-    QCOMPARE(closeFrameReceivedSpy.count(), 1);
-    QCOMPARE(textFrameReceivedSpy.count(), 0);
-    QCOMPARE(textMessageReceivedSpy.count(), 0);
-    QCOMPARE(binaryFrameReceivedSpy.count(), 0);
-    QCOMPARE(binaryMessageReceivedSpy.count(), 0);
+    QCOMPARE(errorReceivedSpy.size(), 0);
+    QCOMPARE(pingReceivedSpy.size(), 0);
+    QCOMPARE(pongReceivedSpy.size(), 0);
+    QCOMPARE(closeFrameReceivedSpy.size(), 1);
+    QCOMPARE(textFrameReceivedSpy.size(), 0);
+    QCOMPARE(textMessageReceivedSpy.size(), 0);
+    QCOMPARE(binaryFrameReceivedSpy.size(), 0);
+    QCOMPARE(binaryMessageReceivedSpy.size(), 0);
     QList<QVariant> arguments = closeFrameReceivedSpy.takeFirst();
     QCOMPARE(arguments.at(0).value<QWebSocketProtocol::CloseCode>(), closeCode);
-    QCOMPARE(arguments.at(1).toString().length(), payload.length());
+    QCOMPARE(arguments.at(1).toString().size(), payload.size());
     buffer.close();
 }
 
@@ -699,14 +677,14 @@ void tst_DataProcessor::nonCharacterCodes()
         buffer.open(QIODevice::ReadOnly);
         dataProcessor.process(&buffer);
 
-        QCOMPARE(errorSpy.count(), 0);
-        QCOMPARE(closeSpy.count(), 0);
-        QCOMPARE(pingFrameSpy.count(), 0);
-        QCOMPARE(pongFrameSpy.count(), 0);
-        QCOMPARE(textFrameSpy.count(), 1);
-        QCOMPARE(textMessageSpy.count(), 1);
-        QCOMPARE(binaryFrameSpy.count(), 0);
-        QCOMPARE(binaryMessageSpy.count(), 0);
+        QCOMPARE(errorSpy.size(), 0);
+        QCOMPARE(closeSpy.size(), 0);
+        QCOMPARE(pingFrameSpy.size(), 0);
+        QCOMPARE(pongFrameSpy.size(), 0);
+        QCOMPARE(textFrameSpy.size(), 1);
+        QCOMPARE(textMessageSpy.size(), 1);
+        QCOMPARE(binaryFrameSpy.size(), 0);
+        QCOMPARE(binaryMessageSpy.size(), 0);
 
         QVariantList arguments = textFrameSpy.takeFirst();
         QCOMPARE(arguments.at(0).value<QString>().toUtf8(), payload);
@@ -724,6 +702,8 @@ void tst_DataProcessor::frameTooSmall()
     QWebSocketDataProcessor dataProcessor;
     QByteArray firstFrame;
 
+    dataProcessor.setIdleTimeout(DefaultIdleTimeout);
+
     firstFrame.append(quint8(QWebSocketProtocol::OpCodeText)).append(char(1))
             .append(QByteArray(1, 'a'));
 
@@ -744,15 +724,15 @@ void tst_DataProcessor::frameTooSmall()
 
     dataProcessor.process(&buffer);
 
-    QTRY_VERIFY_WITH_TIMEOUT(errorSpy.count(), 7000);
-    QCOMPARE(errorSpy.count(), 1);
-    QCOMPARE(closeSpy.count(), 0);
-    QCOMPARE(pingMessageSpy.count(), 0);
-    QCOMPARE(pongMessageSpy.count(), 0);
-    QCOMPARE(textMessageSpy.count(), 0);
-    QCOMPARE(binaryMessageSpy.count(), 0);
-    QCOMPARE(textFrameSpy.count(), 0);
-    QCOMPARE(binaryFrameSpy.count(), 0);
+    QTRY_VERIFY_WITH_TIMEOUT(errorSpy.size(), 7000);
+    QCOMPARE(errorSpy.size(), 1);
+    QCOMPARE(closeSpy.size(), 0);
+    QCOMPARE(pingMessageSpy.size(), 0);
+    QCOMPARE(pongMessageSpy.size(), 0);
+    QCOMPARE(textMessageSpy.size(), 0);
+    QCOMPARE(binaryMessageSpy.size(), 0);
+    QCOMPARE(textFrameSpy.size(), 0);
+    QCOMPARE(binaryFrameSpy.size(), 0);
 
     QList<QVariant> arguments = errorSpy.takeFirst();
     QCOMPARE(arguments.at(0).value<QWebSocketProtocol::CloseCode>(),
@@ -777,15 +757,15 @@ void tst_DataProcessor::frameTooSmall()
 
     dataProcessor.process(&buffer);
 
-    QTRY_VERIFY_WITH_TIMEOUT(errorSpy.count(), 7000);
-    QCOMPARE(errorSpy.count(), 1);
-    QCOMPARE(closeSpy.count(), 0);
-    QCOMPARE(pingMessageSpy.count(), 0);
-    QCOMPARE(pongMessageSpy.count(), 0);
-    QCOMPARE(textMessageSpy.count(), 0);
-    QCOMPARE(binaryMessageSpy.count(), 0);
-    QCOMPARE(textFrameSpy.count(), 0);
-    QCOMPARE(binaryFrameSpy.count(), 0);
+    QTRY_VERIFY_WITH_TIMEOUT(errorSpy.size(), 7000);
+    QCOMPARE(errorSpy.size(), 1);
+    QCOMPARE(closeSpy.size(), 0);
+    QCOMPARE(pingMessageSpy.size(), 0);
+    QCOMPARE(pongMessageSpy.size(), 0);
+    QCOMPARE(textMessageSpy.size(), 0);
+    QCOMPARE(binaryMessageSpy.size(), 0);
+    QCOMPARE(textFrameSpy.size(), 0);
+    QCOMPARE(binaryFrameSpy.size(), 0);
 
     arguments = errorSpy.takeFirst();
     QCOMPARE(arguments.at(0).value<QWebSocketProtocol::CloseCode>(),
@@ -810,15 +790,15 @@ void tst_DataProcessor::frameTooSmall()
 
         dataProcessor.process(&buffer);
 
-        QTRY_VERIFY_WITH_TIMEOUT(errorSpy.count(), 7000);
-        QCOMPARE(errorSpy.count(), 1);
-        QCOMPARE(closeSpy.count(), 0);
-        QCOMPARE(pingMessageSpy.count(), 0);
-        QCOMPARE(pongMessageSpy.count(), 0);
-        QCOMPARE(textMessageSpy.count(), 0);
-        QCOMPARE(binaryMessageSpy.count(), 0);
-        QCOMPARE(textFrameSpy.count(), 1);
-        QCOMPARE(binaryFrameSpy.count(), 0);
+        QTRY_VERIFY_WITH_TIMEOUT(errorSpy.size(), 7000);
+        QCOMPARE(errorSpy.size(), 1);
+        QCOMPARE(closeSpy.size(), 0);
+        QCOMPARE(pingMessageSpy.size(), 0);
+        QCOMPARE(pongMessageSpy.size(), 0);
+        QCOMPARE(textMessageSpy.size(), 0);
+        QCOMPARE(binaryMessageSpy.size(), 0);
+        QCOMPARE(textFrameSpy.size(), 1);
+        QCOMPARE(binaryFrameSpy.size(), 0);
 
         errorSpy.clear();
         closeSpy.clear();
@@ -838,15 +818,15 @@ void tst_DataProcessor::frameTooSmall()
         buffer.open(QIODevice::ReadOnly);
         dataProcessor.process(&buffer);
 
-        QTRY_VERIFY_WITH_TIMEOUT(errorSpy.count(), 7000);
-        QCOMPARE(errorSpy.count(), 1);
-        QCOMPARE(closeSpy.count(), 0);
-        QCOMPARE(pingMessageSpy.count(), 0);
-        QCOMPARE(pongMessageSpy.count(), 0);
-        QCOMPARE(textMessageSpy.count(), 0);
-        QCOMPARE(binaryMessageSpy.count(), 0);
-        QCOMPARE(textFrameSpy.count(), 0);
-        QCOMPARE(binaryFrameSpy.count(), 0);
+        QTRY_VERIFY_WITH_TIMEOUT(errorSpy.size(), 7000);
+        QCOMPARE(errorSpy.size(), 1);
+        QCOMPARE(closeSpy.size(), 0);
+        QCOMPARE(pingMessageSpy.size(), 0);
+        QCOMPARE(pongMessageSpy.size(), 0);
+        QCOMPARE(textMessageSpy.size(), 0);
+        QCOMPARE(binaryMessageSpy.size(), 0);
+        QCOMPARE(textFrameSpy.size(), 0);
+        QCOMPARE(binaryFrameSpy.size(), 0);
 
         QList<QVariant> arguments = errorSpy.takeFirst();
         QCOMPARE(arguments.at(0).value<QWebSocketProtocol::CloseCode>(),
@@ -868,15 +848,15 @@ void tst_DataProcessor::frameTooSmall()
         buffer.open(QIODevice::ReadOnly);
         dataProcessor.process(&buffer);
 
-        QTRY_VERIFY_WITH_TIMEOUT(errorSpy.count(), 7000);
-        QCOMPARE(errorSpy.count(), 1);
-        QCOMPARE(closeSpy.count(), 0);
-        QCOMPARE(pingMessageSpy.count(), 0);
-        QCOMPARE(pongMessageSpy.count(), 0);
-        QCOMPARE(textMessageSpy.count(), 0);
-        QCOMPARE(binaryMessageSpy.count(), 0);
-        QCOMPARE(textFrameSpy.count(), 1);
-        QCOMPARE(binaryFrameSpy.count(), 0);
+        QTRY_VERIFY_WITH_TIMEOUT(errorSpy.size(), 7000);
+        QCOMPARE(errorSpy.size(), 1);
+        QCOMPARE(closeSpy.size(), 0);
+        QCOMPARE(pingMessageSpy.size(), 0);
+        QCOMPARE(pongMessageSpy.size(), 0);
+        QCOMPARE(textMessageSpy.size(), 0);
+        QCOMPARE(binaryMessageSpy.size(), 0);
+        QCOMPARE(textFrameSpy.size(), 1);
+        QCOMPARE(binaryFrameSpy.size(), 0);
 
         buffer.close();
         data.clear();
@@ -897,15 +877,15 @@ void tst_DataProcessor::frameTooSmall()
         buffer.open(QIODevice::ReadOnly);
 
         dataProcessor.process(&buffer);
-        QTRY_VERIFY_WITH_TIMEOUT(errorSpy.count(), 7000);
-        QCOMPARE(errorSpy.count(), 1);
-        QCOMPARE(closeSpy.count(), 0);
-        QCOMPARE(pingMessageSpy.count(), 0);
-        QCOMPARE(pongMessageSpy.count(), 0);
-        QCOMPARE(textMessageSpy.count(), 0);
-        QCOMPARE(binaryMessageSpy.count(), 0);
-        QCOMPARE(textFrameSpy.count(), 0);
-        QCOMPARE(binaryFrameSpy.count(), 0);
+        QTRY_VERIFY_WITH_TIMEOUT(errorSpy.size(), 7000);
+        QCOMPARE(errorSpy.size(), 1);
+        QCOMPARE(closeSpy.size(), 0);
+        QCOMPARE(pingMessageSpy.size(), 0);
+        QCOMPARE(pongMessageSpy.size(), 0);
+        QCOMPARE(textMessageSpy.size(), 0);
+        QCOMPARE(binaryMessageSpy.size(), 0);
+        QCOMPARE(textFrameSpy.size(), 0);
+        QCOMPARE(binaryFrameSpy.size(), 0);
         arguments = errorSpy.takeFirst();
         QCOMPARE(arguments.at(0).value<QWebSocketProtocol::CloseCode>(),
                  QWebSocketProtocol::CloseCodeGoingAway);
@@ -1020,7 +1000,7 @@ void tst_DataProcessor::invalidControlFrame_data()
             << QByteArray()
             << false
             << QWebSocketProtocol::CloseCodeProtocolError;
-    QTest::newRow("Close control frame with payload size 126")
+    QTest::newRow("Pong control frame with payload size 126")
             << quint8(FIN | QWebSocketProtocol::OpCodePong)
             << quint8(126)
             << QByteArray()
@@ -1375,19 +1355,21 @@ void tst_DataProcessor::invalidPayloadInCloseFrame()
     QSignalSpy textFrameSpy(&dataProcessor, SIGNAL(textFrameReceived(QString,bool)));
     QSignalSpy binaryFrameSpy(&dataProcessor, SIGNAL(binaryFrameReceived(QByteArray,bool)));
 
+    dataProcessor.setIdleTimeout(DefaultIdleTimeout);
+
     data.append(firstByte).append(secondByte);
     data.append(payload);
     buffer.setData(data);
     buffer.open(QIODevice::ReadOnly);
     dataProcessor.process(&buffer);
-    QCOMPARE(closeSpy.count(), 1);
-    QCOMPARE(errorSpy.count(), 0);
-    QCOMPARE(pingMessageSpy.count(), 0);
-    QCOMPARE(pongMessageSpy.count(), 0);
-    QCOMPARE(textMessageSpy.count(), 0);
-    QCOMPARE(binaryMessageSpy.count(), 0);
-    QCOMPARE(textFrameSpy.count(), 0);
-    QCOMPARE(binaryFrameSpy.count(), 0);
+    QCOMPARE(closeSpy.size(), 1);
+    QCOMPARE(errorSpy.size(), 0);
+    QCOMPARE(pingMessageSpy.size(), 0);
+    QCOMPARE(pongMessageSpy.size(), 0);
+    QCOMPARE(textMessageSpy.size(), 0);
+    QCOMPARE(binaryMessageSpy.size(), 0);
+    QCOMPARE(textFrameSpy.size(), 0);
+    QCOMPARE(binaryFrameSpy.size(), 0);
     QVariantList arguments = closeSpy.takeFirst();
     QCOMPARE(arguments.at(0).value<QWebSocketProtocol::CloseCode>(), expectedCloseCode);
     buffer.close();
@@ -1475,6 +1457,8 @@ void tst_DataProcessor::doTest(int timeout)
     QSignalSpy textFrameSpy(&dataProcessor, SIGNAL(textFrameReceived(QString,bool)));
     QSignalSpy binaryFrameSpy(&dataProcessor, SIGNAL(binaryFrameReceived(QByteArray,bool)));
 
+    dataProcessor.setIdleTimeout(DefaultIdleTimeout);
+
     if (isContinuationFrame)
     {
         data.append(quint8(QWebSocketProtocol::OpCodeText))
@@ -1486,12 +1470,12 @@ void tst_DataProcessor::doTest(int timeout)
     buffer.setData(data);
     buffer.open(QIODevice::ReadOnly);
     dataProcessor.process(&buffer);
-    QTRY_VERIFY_WITH_TIMEOUT(errorSpy.count(), timeout);
-    QCOMPARE(errorSpy.count(), 1);
-    QCOMPARE(textMessageSpy.count(), 0);
-    QCOMPARE(binaryMessageSpy.count(), 0);
-    QCOMPARE(textFrameSpy.count(), isContinuationFrame ? 1 : 0);
-    QCOMPARE(binaryFrameSpy.count(), 0);
+    QTRY_VERIFY_WITH_TIMEOUT(errorSpy.size(), timeout);
+    QCOMPARE(errorSpy.size(), 1);
+    QCOMPARE(textMessageSpy.size(), 0);
+    QCOMPARE(binaryMessageSpy.size(), 0);
+    QCOMPARE(textFrameSpy.size(), isContinuationFrame ? 1 : 0);
+    QCOMPARE(binaryFrameSpy.size(), 0);
     QVariantList arguments = errorSpy.takeFirst();
     QCOMPARE(arguments.at(0).value<QWebSocketProtocol::CloseCode>(), expectedCloseCode);
     buffer.close();
@@ -1521,17 +1505,19 @@ void tst_DataProcessor::doCloseFrameTest()
     QSignalSpy textFrameSpy(&dataProcessor, SIGNAL(textFrameReceived(QString,bool)));
     QSignalSpy binaryFrameSpy(&dataProcessor, SIGNAL(binaryFrameReceived(QByteArray,bool)));
 
+    dataProcessor.setIdleTimeout(DefaultIdleTimeout);
+
     data.append(firstByte).append(secondByte);
     data.append(payload);
     buffer.setData(data);
     buffer.open(QIODevice::ReadOnly);
     dataProcessor.process(&buffer);
-    QCOMPARE(closeSpy.count(), 1);
-    QCOMPARE(errorSpy.count(), 0);
-    QCOMPARE(textMessageSpy.count(), 0);
-    QCOMPARE(binaryMessageSpy.count(), 0);
-    QCOMPARE(textFrameSpy.count(), 0);
-    QCOMPARE(binaryFrameSpy.count(), 0);
+    QCOMPARE(closeSpy.size(), 1);
+    QCOMPARE(errorSpy.size(), 0);
+    QCOMPARE(textMessageSpy.size(), 0);
+    QCOMPARE(binaryMessageSpy.size(), 0);
+    QCOMPARE(textFrameSpy.size(), 0);
+    QCOMPARE(binaryFrameSpy.size(), 0);
     QVariantList arguments = closeSpy.takeFirst();
     QCOMPARE(arguments.at(0).value<QWebSocketProtocol::CloseCode>(), expectedCloseCode);
     buffer.close();
@@ -1703,7 +1689,7 @@ void tst_DataProcessor::invalidUTF8(const char *dataTag, const char *utf8Sequenc
         QTest::newRow(QStringLiteral("Close frame with invalid UTF8-sequence: %1")
                       .arg(dataTag).toLatin1().constData())
                 << quint8(FIN | QWebSocketProtocol::OpCodeClose)
-                << quint8(payload.length() + 2)
+                << quint8(payload.size() + 2)
                 << QByteArray(wireRepresentation, 2).append(payload)
                 << false
                 << QWebSocketProtocol::CloseCodeWrongDatatype;
@@ -1713,7 +1699,7 @@ void tst_DataProcessor::invalidUTF8(const char *dataTag, const char *utf8Sequenc
         QTest::newRow(QStringLiteral("Text frame with invalid UTF8-sequence: %1")
                       .arg(dataTag).toLatin1().constData())
                 << quint8(FIN | QWebSocketProtocol::OpCodeText)
-                << quint8(payload.length())
+                << quint8(payload.size())
                 << payload
                 << false
                 << QWebSocketProtocol::CloseCodeWrongDatatype;
@@ -1721,7 +1707,7 @@ void tst_DataProcessor::invalidUTF8(const char *dataTag, const char *utf8Sequenc
         QTest::newRow(QStringLiteral("Continuation text frame with invalid UTF8-sequence: %1")
                       .arg(dataTag).toLatin1().constData())
                 << quint8(FIN | QWebSocketProtocol::OpCodeContinue)
-                << quint8(payload.length())
+                << quint8(payload.size())
                 << payload
                 << true
                 << QWebSocketProtocol::CloseCodeWrongDatatype;
@@ -1861,10 +1847,11 @@ void tst_DataProcessor::clearDataBuffers()
     const QByteArray binaryData("Hello!");
     QByteArray data;
     data.append(char(FIN | QWebSocketProtocol::OpCodeBinary));
-    data.append(char(binaryData.length()));
+    data.append(char(binaryData.size()));
     data.append(binaryData);
 
     QWebSocketDataProcessor dataProcessor;
+    dataProcessor.setIdleTimeout(DefaultIdleTimeout);
     connect(&dataProcessor, &QWebSocketDataProcessor::binaryMessageReceived,
             [&binaryData](const QByteArray &message)
     {
